@@ -24,12 +24,13 @@ describe 'murano::dashboard' do
       :order  => 2,
     })}
 
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_API_URL = 'http:\/\/127.0.0.1:8082'/)}
+    it { is_expected.to_not contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_API_URL = /)}
     it { is_expected.to_not contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_REPO_URL = /)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MAX_FILE_SIZE_MB = '5'/)}
-    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/METADATA_CACHE_DIR = '\/var\/cache\/muranodashboard-cache'/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/METADATA_CACHE_DIR = '\/var\/cache\/murano-dashboard'/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranodashboard'\] = \{'handlers': \['syslog'\], 'level': 'DEBUG'\}/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranoclient'\] = \{'handlers': \['syslog'\], 'level': 'ERROR'\}/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_USE_GLARE = False/)}
 
     it { is_expected.to contain_exec('clean_horizon_config').with({
       :command => 'sed -e \'/^## MURANO_CONFIG_BEGIN/,/^## MURANO_CONFIG_END ##/ d\' -i /etc/openstack-dashboard/local_settings.py',
@@ -45,7 +46,7 @@ describe 'murano::dashboard' do
     })}
 
     it { is_expected.to contain_exec('django_syncdb').with({
-      :command => '/usr/share/openstack-dashboard/manage.py syncdb --noinput'
+      :command => '/usr/share/openstack-dashboard/manage.py migrate --noinput'
     })}
   end
 
@@ -53,9 +54,11 @@ describe 'murano::dashboard' do
     let :params do {
       :api_url               => 'http://127.0.0.1:8083',
       :repo_url              => 'http://storage.apps.openstack.com',
+      :enable_glare          => true,
       :collect_static_script => '/bin/openstack-dashboard/manage.py',
       :metadata_dir          => '/tmp/muranodashboard-cache',
       :max_file_size         => '5',
+      :sync_db               => false,
     }
     end
 
@@ -82,6 +85,7 @@ describe 'murano::dashboard' do
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/METADATA_CACHE_DIR = '\/tmp\/muranodashboard-cache'/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranodashboard'\] = \{'handlers': \['syslog'\], 'level': 'DEBUG'\}/)}
     it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/LOGGING\['loggers'\]\['muranoclient'\] = \{'handlers': \['syslog'\], 'level': 'ERROR'\}/)}
+    it { is_expected.to contain_concat__fragment('murano_dashboard_section').with_content(/MURANO_USE_GLARE = True/)}
 
     it { is_expected.to contain_exec('clean_horizon_config').with({
       :command => 'sed -e \'/^## MURANO_CONFIG_BEGIN/,/^## MURANO_CONFIG_END ##/ d\' -i /etc/openstack-dashboard/local_settings.py',
@@ -96,7 +100,7 @@ describe 'murano::dashboard' do
       :command => '/bin/openstack-dashboard/manage.py compress --force'
     })}
 
-    it { is_expected.to contain_exec('django_syncdb').with({
+    it { is_expected.to_not contain_exec('django_syncdb').with({
       :command => '/bin/openstack-dashboard/manage.py syncdb --noinput'
     })}
   end
